Platform specific implementations.
Platform specific implementations.
(input-stream->binary-coercion in md-create-fn)Consume in and return exactly the same hash coercion as a byte array with
the same contents. The caller owns and closes the stream.
Hasch represents binaries shorter than split-size directly (with collision
escaping), and larger binaries by their digest. Buffering at most
split-size bytes lets an unknown-length stream select the same representation
without materializing a large value.
Consume `in` and return exactly the same hash coercion as a byte array with the same contents. The caller owns and closes the stream. Hasch represents binaries shorter than `split-size` directly (with collision escaping), and larger binaries by their digest. Buffering at most `split-size` bytes lets an unknown-length stream select the same representation without materializing a large value.
(sha256 bs)Raw SHA-256 digest of a byte-array -> byte-array.
Raw SHA-256 digest of a byte-array -> byte-array.
(sha512 bs)Raw SHA-512 digest of a byte-array -> byte-array.
Raw SHA-512 digest of a byte-array -> byte-array.
(uuid4)Generates a UUID version 4 (random).
Generates a UUID version 4 (random).
(uuid5 sha-hash)Generates a UUID version 5 from a sha-1 hash byte sequence. Our hash version is coded in first 2 bits.
Generates a UUID version 5 from a sha-1 hash byte sequence. Our hash version is coded in first 2 bits.
Generates a uuid5 from a sha-1 hash byte sequence. Our hash version is coded in first 2 bits.
Generates a uuid5 from a sha-1 hash byte sequence. Our hash version is coded in first 2 bits.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |